@@ -61,7 +61,7 @@ class Server:
             result = response[len(command_string)-1:-1]
             return result
 
-        def _get_players(self):
+        def get_players(self):
             """
             Get Players
             """
@@ -101,6 +101,6 @@ class Server:
             """
             self._connect()
             self._login()
-            self._get_players()
+            self.get_players()
             
 
